#!/usr/local/bin/python
from discord.ext import commands
import core_utils
import discord
import os

intents = discord.Intents.default()
intents.message_content = True
intents.members = True
intents.reactions = True
bot = commands.Bot(command_prefix="!", intents=intents)

cogfiles = [
    f"cogs.{filename[:-3]}"
    for filename in os.listdir("/app/cogs/")
    if filename.endswith(".py")
]

for cogfile in cogfiles:
    bot.load_extension(cogfile)

# import requests_cache
# requests_cache.install_cache(expire_after=300)


@bot.event
async def on_ready():
    print(f"{bot.user.name} has connected to Discord!")
    if os.getenv("DRAGON_ENV") == "prod":
        # await bot.get_channel(152921472304676865).send("I have reconnected")

        # Waiting-room in zoid's server
        channel_id = 1026281775984549958
        message_id = 1099374735428681758

        # for testing, bot-testing server's channel
        # channel_id = 932476007439552522
        # message_id = 1114045480129806361

        blurb = """# Please react to this message with one of the following emojis to be granted the appropriate role(s):

🚀 for Star Citizen

🐜 for HellDivers

<:palsphere:1201663585596481586> for Palworld

🐀 for Darktide/Vermintide

:gear: for Lethal Company

🤖 for Warframe

🚔 for Ready or Not/Ground Branch

🔫 for Tarkov
        """
        # message = await bot.get_channel(channel_id).send(blurb)
        # Update the message on_ready to match the content we always want to be there
        message = await bot.get_channel(channel_id).fetch_message(message_id)
        await message.edit(content=blurb)


@bot.event
async def on_raw_reaction_add(payload):
    guild = bot.get_guild(payload.guild_id)

    role_map = {
        "🔫": "Tarkov Gamers",
        "🤖": "Warframe Enjoyers",
        "🐀": "Dorktide Gamers",
        "🐜": "Hell Divers",
        "🚀": "Star Citizens",
        "⚙️": "Lethal Gamers",
        "🚔": "Ready or Notters",
        "palsphere": "Palworlders",
    }

    if payload.channel_id == 1026281775984549958:
        role = discord.utils.get(guild.roles, name=role_map[payload.emoji.name])
        member = guild.get_member(payload.user_id)
        await member.add_roles(role)


@bot.listen("on_message")
async def convert_heic_to_jpg(ctx):
    from cmagick import cmagick
    import time
    import tempfile

    if ctx.attachments:
        for attachment in ctx.attachments:
            if attachment.filename.lower().endswith(("heic", "tiff")):
                source_file = "/tmp/source"
                source_file, file_path = tempfile.mkstemp()
                jpg_file = "/tmp/%s.jpg" % time.time()
                await attachment.save(fp=file_path)

                img = cmagick.convert(file_path, jpg_file)

                try:
                    await ctx.delete()
                except Exception:
                    pass
                await ctx.channel.send(
                    "%s said:\n%s" % (ctx.author.mention, ctx.content),
                    file=discord.File(jpg_file),
                )
                os.remove(file_path)
        return


@bot.listen("on_message")
async def fix_social_media_links(ctx):
    correct_domains = {
        "https://x.com": "vxtwitter",
        "https://www.x.com": "vxtwitter",
        "https://twitter.com": "vxtwitter",
        "https://www.twitter.com": "vxtwitter",
        "https://tiktok.com": "vxtiktok",
        "https://www.tiktok.com": "vxtiktok",
    }
    if ctx.author.id == bot.user.id:
        return
    for k in correct_domains.keys():
        if k in ctx.content or "www.%s.com" % k in ctx.content:
            await ctx.channel.send(
                "%s said:\n%s"
                % (
                    ctx.author.mention,
                    ctx.content.replace(k, "https://%s.com" % correct_domains[k]).split(
                        "?s"
                    )[0],
                )
            )
            await ctx.delete()
            return


@bot.event
async def on_message(ctx):
    if str(bot.user.id) in ctx.content:
        import wolframalpha

        client = wolframalpha.Client(os.getenv("wolfram_token"))
        query = " ".join(ctx.content.split()[1:])
        try:
            res = client.query(query)
            return await ctx.reply(next(res.results).text)
        except Exception as e:
            print(e)
            return await ctx.reply("Sorry, I'm unable to answer that")


bot.run(os.getenv("discord_token"))
